# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._enums import *

__all__ = ['DeployArgs', 'Deploy']

@pulumi.input_type
class DeployArgs:
    def __init__(__self__, *,
                 clear_cache: Optional[pulumi.Input['DeployClearCache']] = None):
        """
        The set of arguments for constructing a Deploy resource.
        """
        if clear_cache is None:
            clear_cache = 'do_not_clear'
        if clear_cache is not None:
            pulumi.set(__self__, "clear_cache", clear_cache)

    @property
    @pulumi.getter(name="clearCache")
    def clear_cache(self) -> Optional[pulumi.Input['DeployClearCache']]:
        return pulumi.get(self, "clear_cache")

    @clear_cache.setter
    def clear_cache(self, value: Optional[pulumi.Input['DeployClearCache']]):
        pulumi.set(self, "clear_cache", value)


class Deploy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 clear_cache: Optional[pulumi.Input['DeployClearCache']] = None,
                 __props__=None):
        """
        Create a Deploy resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DeployArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Deploy resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param DeployArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeployArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 clear_cache: Optional[pulumi.Input['DeployClearCache']] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeployArgs.__new__(DeployArgs)

            if clear_cache is None:
                clear_cache = 'do_not_clear'
            __props__.__dict__["clear_cache"] = clear_cache
            __props__.__dict__["commit"] = None
        super(Deploy, __self__).__init__(
            'render:services:Deploy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Deploy':
        """
        Get an existing Deploy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = DeployArgs.__new__(DeployArgs)

        __props__.__dict__["clear_cache"] = None
        __props__.__dict__["commit"] = None
        return Deploy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clearCache")
    def clear_cache(self) -> pulumi.Output[Optional['DeployClearCache']]:
        return pulumi.get(self, "clear_cache")

    @property
    @pulumi.getter
    def commit(self) -> pulumi.Output[Optional['outputs.DeployCommit']]:
        return pulumi.get(self, "commit")

