# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'CustomDomainDomainType',
    'CustomDomainVerificationStatus',
    'DeployClearCache',
    'StaticSiteServiceAutoDeploy',
    'StaticSiteServiceNotifyOnFail',
    'StaticSiteServiceSuspended',
    'StaticSiteStaticSiteRouteType',
    'StaticSiteStaticSiteServiceDetailsPullRequestPreviewsEnabled',
    'WebServiceServiceAutoDeploy',
    'WebServiceServiceNotifyOnFail',
    'WebServiceServiceSuspended',
    'WebServiceWebServiceServiceDetailsEnv',
    'WebServiceWebServiceServiceDetailsPlan',
    'WebServiceWebServiceServiceDetailsPullRequestPreviewsEnabled',
    'WebServiceWebServiceServiceDetailsRegion',
]


class CustomDomainDomainType(str, Enum):
    APEX = "apex"
    SUBDOMAIN = "subdomain"


class CustomDomainVerificationStatus(str, Enum):
    VERIFIED = "verified"
    UNVERIFIED = "unverified"


class DeployClearCache(str, Enum):
    DO_NOT_CLEAR = "do_not_clear"
    CLEAR = "clear"


class StaticSiteServiceAutoDeploy(str, Enum):
    """
    Whether to auto deploy the service or not upon git push.
    """
    YES = "yes"
    NO = "no"


class StaticSiteServiceNotifyOnFail(str, Enum):
    """
    The notification setting for this service upon deployment failure.
    """
    DEFAULT = "default"
    NOTIFY = "notify"
    IGNORE = "ignore"


class StaticSiteServiceSuspended(str, Enum):
    SUSPENDED = "suspended"
    NOT_SUSPENDED = "not_suspended"


class StaticSiteStaticSiteRouteType(str, Enum):
    REDIRECT = "redirect"
    REWRITE = "rewrite"


class StaticSiteStaticSiteServiceDetailsPullRequestPreviewsEnabled(str, Enum):
    YES = "yes"
    NO = "no"


class WebServiceServiceAutoDeploy(str, Enum):
    """
    Whether to auto deploy the service or not upon git push.
    """
    YES = "yes"
    NO = "no"


class WebServiceServiceNotifyOnFail(str, Enum):
    """
    The notification setting for this service upon deployment failure.
    """
    DEFAULT = "default"
    NOTIFY = "notify"
    IGNORE = "ignore"


class WebServiceServiceSuspended(str, Enum):
    SUSPENDED = "suspended"
    NOT_SUSPENDED = "not_suspended"


class WebServiceWebServiceServiceDetailsEnv(str, Enum):
    DOCKER = "docker"
    ELIXIR = "elixir"
    GO = "go"
    NODE = "node"
    PYTHON = "python"
    RUBY = "ruby"
    RUST = "rust"


class WebServiceWebServiceServiceDetailsPlan(str, Enum):
    STARTER = "starter"
    STARTER_PLUS = "starter_plus"
    STANDARD = "standard"
    STANDARD_PLUS = "standard_plus"
    PRO = "pro"
    PRO_PLUS = "pro_plus"
    PRO_MAX = "pro_max"
    PRO_ULTRA = "pro_ultra"


class WebServiceWebServiceServiceDetailsPullRequestPreviewsEnabled(str, Enum):
    YES = "yes"
    NO = "no"


class WebServiceWebServiceServiceDetailsRegion(str, Enum):
    OREGON = "oregon"
    FRANKFURT = "frankfurt"
